@@ -1,4 +1,5 @@
 from . import websocket
+from .websocket.defaults import MIN_PYTHON_MINOR, MIN_PYTHON_MAJOR, UPDATE_NOTIFICATION_SLEEP_TIME
 
 import sys
 import subprocess
@@ -9,10 +10,7 @@ from distutils import version
 
 init()
 
-__version__ = '0.3.12'
-MIN_PYTHON_MAJOR = 3
-MIN_PYTHON_MINOR = 7
-update_notification_sleep_time = 15
+__version__ = '0.3.13'
 
 try:
     user_python_verison = sys.version_info
@@ -35,10 +33,10 @@ try:
               f"\tIt is highly advisable that you keep your libraries up-to-date... Please upgrade your library using-\n"
               f"\n\t\t python3.7 -m pip install --upgrade truedata_ws\n"
               f"\tWe also strongly recommend you read our release notes at the end of the README.md that is found at the end of PyPi page (found at: https://pypi.org/project/truedata-ws/){Style.RESET_ALL}")
-        while update_notification_sleep_time >= 0:
+        while UPDATE_NOTIFICATION_SLEEP_TIME >= 0:
             sleep(1)
-            print(f'{Style.BRIGHT}{Fore.GREEN}Your code will resume in {update_notification_sleep_time} secs...{Style.RESET_ALL}', end='\r')
-            update_notification_sleep_time = update_notification_sleep_time - 1
+            print(f'{Style.BRIGHT}{Fore.GREEN}Your code will resume in {UPDATE_NOTIFICATION_SLEEP_TIME} secs...{Style.RESET_ALL}', end='\r')
+            update_notification_sleep_time = UPDATE_NOTIFICATION_SLEEP_TIME - 1
         print('\n')
 except Exception as e:
     print(f'{Style.BRIGHT}{Fore.RED}\tUnable to get latest version from PyPi...\n'
