@@ -31,7 +31,7 @@ class TDInvalidRequestError(Exception):
 class LiveClient(WebSocketApp):
 
     def __init__(self, parent_app, url, *args):
-        WebSocketApp.__init__(self, url, on_error=self.ws_error, on_message=self.on_msg_func, *args)
+        WebSocketApp.__init__(self, url, on_open=self.ws_open, on_error=self.ws_error, on_message=self.on_msg_func, *args)
         self.segments = []
         self.max_symbols = 0
         self.remaining_symbols = 0
@@ -57,18 +57,16 @@ class LiveClient(WebSocketApp):
 
     def handle_message_data(self, msg):
         # print(f"Truedata has this message for you -> {msg['message']}")
-        if msg['message'] == 'TrueData Real Time Data Service':  # Connection success message
-            print(f"You have subscribed for {msg['maxsymbols']} symbols across {msg['segments']} until {msg['validity']} with type of stream as {msg['subscription']}...")
-            self.subscription_type = msg['subscription']
-        if msg['message'] == 'invalid request':
-            print('raising request error')
-            raise TDInvalidRequestError
-        if msg['message'] == 'symbols added':
-            self.add_contract_details(msg['symbollist'])
-        if msg['message'] == 'symbols removed':
-            pass
-        if msg['message'] == "Invalid User Credentials":
-            print(f'{Style.BRIGHT}{Fore.RED}Connection failed due to Invalid User Credentials...{Style.RESET_ALL}')
+        if msg['success']:
+            if msg['message'] == 'TrueData Real Time Data Service':  # Connection success message
+                print(f"You have subscribed for {msg['maxsymbols']} symbols across {msg['segments']} until {msg['validity']} with type of stream as {msg['subscription']}...")
+                self.subscription_type = msg['subscription']
+            elif msg['message'] == 'symbols added':
+                self.add_contract_details(msg['symbollist'])
+            elif msg['message'] == 'symbols removed':
+                pass
+        else:
+            print(f"{Style.BRIGHT}{Fore.RED}The request encountered an error - {msg['message']}{Style.BRIGHT}{Fore.RED}")
 
     def add_contract_details(self, contracts_list):
         for contract in contracts_list:
@@ -121,7 +119,9 @@ class LiveClient(WebSocketApp):
                     del self.parent_app.live_data[ticker_id].best_ask_price
                     del self.parent_app.live_data[ticker_id].best_ask_qty
         except KeyError:
-            print(f'{Style.BRIGHT}{Fore.RED}This symbol(tick) is not tied to any req_id...{Style.RESET_ALL}')
+            pass
+        except Exception as e:
+            print(f'{Style.BRIGHT}{Fore.RED}Encountered with tick feed - {e}{Style.RESET_ALL}')
 
     def handle_bid_ask_data(self, bidask_tick):
         try:
@@ -134,7 +134,9 @@ class LiveClient(WebSocketApp):
                 self.parent_app.live_data[ticker_id].best_ask_price = float(bidask_tick[4])
                 self.parent_app.live_data[ticker_id].best_ask_qty = int(bidask_tick[5])
         except KeyError:
-            print(f'{Style.BRIGHT}{Fore.RED}This symbol(bid-ask) is not tied to any req_id...{Style.RESET_ALL}')
+            pass
+        except Exception as e:
+            print(f'{Style.BRIGHT}{Fore.RED}Encountered with bid-ask feed - {e}{Style.RESET_ALL}')
 
     def handle_bar_data(self, bar_data):
         try:
@@ -157,11 +159,17 @@ class LiveClient(WebSocketApp):
                 # Calculating addn data
                 self.parent_app.live_data[ticker_id].calculate_additional_data()
         except KeyError:
-            print(f'{Style.BRIGHT}{Fore.RED}This symbol(bar) is not tied to any req_id...{Style.RESET_ALL}')
+            pass
+        except Exception as e:
+            print(f'{Style.BRIGHT}{Fore.RED}Encountered with bar feed - {e}{Style.RESET_ALL}')
 
     def ws_error(self, error):
         print(error)
 
+    def ws_open(self, message):
+        # self.sock.settimeout(300)
+        print(message)
+
 
 class HistoricalWebsocket:
     def __init__(self, login_id, password, url, historical_port, broker_token):
@@ -183,12 +191,16 @@ class HistoricalWebsocket:
             self.hist_socket.close()
 
     def get_hist_bar_data(self, contract, end_time, start_time, bar_size):
-        # print(f'{{"method": "gethistory", "interval": "{bar_size}", "symbol": "{contract}", "from": "{start_time}", "to": "{end_time}"}}')
         self.hist_socket.send(f'{{"method": "gethistory", "interval": "{bar_size}", "symbol": "{contract}", "from": "{start_time}", "to": "{end_time}"}}')
         raw_hist_data = self.hist_socket.recv()
-        hist_data = json.loads(raw_hist_data)['data']
-        hist_data = self.hist_bar_data_to_dict_list(hist_data, contract)
-        return hist_data
+        json_response = json.loads(raw_hist_data)
+        if json_response['success']:
+            hist_data = json_response['data']
+            hist_data = self.hist_bar_data_to_dict_list(hist_data, contract)
+            return hist_data
+        else:
+            print(f'{Style.BRIGHT}{Fore.RED}ERROR: Your request failed with error "{json_response["message"]}"{Style.RESET_ALL}')
+            return []
 
     @staticmethod
     def hist_bar_data_to_dict_list(hist_data, contract):  # No need for symbol other than printing
@@ -210,11 +222,17 @@ class HistoricalWebsocket:
         return data_list
 
     def get_hist_tick_data(self, contract, end_time, start_time):
+        print(f'{{"method": "gethistory", "interval": "tick", "symbol": "{contract}", "from": "{start_time}", "to": "{end_time}"}}')
         self.hist_socket.send(f'{{"method": "gethistory", "interval": "tick", "symbol": "{contract}", "from": "{start_time}", "to": "{end_time}"}}')
         raw_hist_data = self.hist_socket.recv()
-        hist_data = json.loads(raw_hist_data)['data']
-        hist_data = self.hist_tick_data_to_dict_list(hist_data, contract)
-        return hist_data
+        json_response = json.loads(raw_hist_data)
+        if json_response['success']:
+            hist_data = json_response['data']
+            hist_data = self.hist_tick_data_to_dict_list(hist_data, contract)
+            return hist_data
+        else:
+            print(f'{Style.BRIGHT}{Fore.RED}ERROR: Your request failed with error "{json_response["message"]}"{Style.RESET_ALL}')
+            return []
 
     @staticmethod
     def hist_tick_data_to_dict_list(hist_data, contract):
